@@ -3,7 +3,8 @@ from xml.etree import ElementTree
 import requests
 
 from quickbase_json.helpers import FileUpload
-from quickbase_json.qb_response import QBResponse
+from quickbase_json.qb_insert_update_response import QBInsertResponse
+from quickbase_json.qb_response import QBResponse, QBQueryResponse
 
 
 class QuickbaseJSONClient:
@@ -52,7 +53,7 @@ class QuickbaseJSONClient:
             print(f'QJAC : query_records : response.json() ---> \n{r.json()}')
 
         # create response object
-        res = QBResponse('records')
+        res = QBQueryResponse(res=r)
 
         # update response object with JSON data from request
         res.update(r.json())
@@ -76,7 +77,13 @@ class QuickbaseJSONClient:
         if self.debug:
             print(f'QJAC : insert_update : body ---> \n{body}')
 
-        return requests.post('https://api.quickbase.com/v1/records', headers=self.headers, json=body).json()
+        r = requests.post('https://api.quickbase.com/v1/records', headers=self.headers, json=body)
+
+        res = QBInsertResponse()
+
+
+
+        return
 
     def delete_records(self, table: str, where: str):
         """
